EML_TARGET_INVALID_ROLE = "The selected target is invalid. We currently support only categorical targets."
EML_TARGET_INVALID_UNIQUE_COUNT = "The selected target is invalid. We currently support only categorical targets with up to 10 classes."
COLUMN_NOT_EXISTS = "The selected target is invalid. No such field exists in the input data."

OUTPUT_RATIO_INVALID = "Invalid output_ratio: %s. The permitted range is %s - %s"
MISSING_TARGET_TABLE = "Missing the target_column argument."
